@@ -7,8 +7,11 @@ use UNIVERSAL::require;
 use Scalar::Util qw/blessed/;
 use FormValidator::Lite::Constraint::Default;
 use FormValidator::Lite::Upload;
+use Class::Accessor::Lite;
 
-our $VERSION = '0.17';
+Class::Accessor::Lite->mk_accessors(qw/query/);
+
+our $VERSION = '0.18';
 
 our $Rules;
 our $FileRules;
@@ -22,14 +25,14 @@ sub new {
     my ($class, $q) = @_;
     Carp::croak("Usage: ${class}->new(\$q)") unless $q;
 
-    bless { _q => $q, _error => {} }, $class;
+    bless { query => $q, _error => {} }, $class;
 }
 
 sub check {
     my ($self, @rule_ary) = @_;
     Carp::croak("this is instance method") unless ref $self;
 
-    my $q = $self->{_q};
+    my $q = $self->{query};
     while (my ($key, $rules) = splice(@rule_ary, 0, 2)) {
         local $_;
         if (ref $key) {
@@ -251,6 +254,12 @@ Create a new instance.
 
 $q is query like object, such as Apache::Request, CGI.pm, Plack::Request.
 
+=item $validator->query()
+
+=item $validator->query($query)
+
+Getter/Setter for query like object.
+
 =item $validator->check(@rule_ary)
 
 This method do validation.
